==> linkchecker-5.0.1.tbz: lib/python2.5/site-packages/_LinkChecker_configdata.py <==
# -*- coding: iso-8859-1 -*-
# this file is automatically created by setup.py
install_purelib = '/usr/local/lib/python2.5/site-packages'
install_platlib = '/usr/local/lib/python2.5/site-packages'
install_lib = '/usr/local/lib/python2.5/site-packages'
install_headers = '/usr/local/include/python2.5/LinkChecker'
install_scripts = '/usr/local/bin'
config_dir = '/usr/local/share/linkchecker'
install_data = '/usr/local'
name = u'LinkChecker'
version = u'5.0.1'
author = u'Bastian Kleineidam'
author_email = u'calvin@users.sourceforge.net'
maintainer = u'Bastian Kleineidam'
maintainer_email = u'calvin@users.sourceforge.net'
url = u'http://linkchecker.sourceforge.net/'
license = u'GPL'
description = u'check websites and HTML documents for broken links'
long_description = u'Linkchecker features:\no recursive and multithreaded checking\no output in colored or normal text, HTML, SQL, CSV, XML or a sitemap\n  graph in different formats\no HTTP/1.1, HTTPS, FTP, mailto:, news:, nntp:, Telnet and local file\n  links support\no restrict link checking with regular expression filters for URLs\no proxy support\no username/password authorization for HTTP, FTP and Telnet\no honors robots.txt exclusion protocol\no Cookie support\no HTML and CSS syntax check\no Antivirus check\no a command line interface\no a (Fast)CGI web interface (requires HTTP server)\n'
keywords = ['link', 'url', 'checking', 'verification']
platforms = ['UNKNOWN']
fullname = u'LinkChecker-5.0.1'
contact = u'Bastian Kleineidam'
contact_email = u'calvin@users.sourceforge.net'
fullname = u'LinkChecker-5.0.1'
appname = "LinkChecker"

==> linkchecker-5.1.tbz: lib/python2.6/site-packages/_LinkChecker_configdata.py <==
# -*- coding: iso-8859-1 -*-
# this file is automatically created by setup.py
install_purelib = '/usr/local/lib/python2.6/site-packages'
install_platlib = '/usr/local/lib/python2.6/site-packages'
install_lib = '/usr/local/lib/python2.6/site-packages'
install_headers = '/usr/local/include/python2.6/LinkChecker'
install_scripts = '/usr/local/bin'
config_dir = '/usr/local/share/linkchecker'
install_data = '/usr/local'
name = u'LinkChecker'
version = u'5.1'
author = u'Bastian Kleineidam'
author_email = u'calvin@users.sourceforge.net'
maintainer = u'Bastian Kleineidam'
maintainer_email = u'calvin@users.sourceforge.net'
url = u'http://linkchecker.sourceforge.net/'
license = u'GPL'
description = u'check websites and HTML documents for broken links'
long_description = u'Linkchecker features:\no recursive and multithreaded checking\no output in colored or normal text, HTML, SQL, CSV, XML or a sitemap\n  graph in different formats\no HTTP/1.1, HTTPS, FTP, mailto:, news:, nntp:, Telnet and local file\n  links support\no restrict link checking with regular expression filters for URLs\no proxy support\no username/password authorization for HTTP, FTP and Telnet\no honors robots.txt exclusion protocol\no Cookie support\no HTML and CSS syntax check\no Antivirus check\no a command line interface\no a (Fast)CGI web interface (requires HTTP server)\n'
keywords = ['link', 'url', 'checking', 'verification']
platforms = ['UNKNOWN']
fullname = u'LinkChecker-5.1'
contact = u'Bastian Kleineidam'
contact_email = u'calvin@users.sourceforge.net'
fullname = u'LinkChecker-5.1'
appname = "LinkChecker"
